VARS = [
    {"name": "license_type", "required": True, "default": "mit"},
    {"name": "product_name", "required": True, "example": "Super fancy product"},
    {"name": "author", "required": True, "example": "John Smith or name of a company"},
    {"name": "year", "required": True, "example": "2018"},
]
