black==22.8.0                       # MIT
coverage==6.4.4                     # Apache-2.0 license
flake8==3.9.2                       # MIT
mock==4.0.3                         # BSD-2-Clause license
pytest==7.1.3                       # MIT
Sphinx==5.1.1                       # BSD-2-Clause license
tox==3.26.0                         # MIT
