[tox]
envlist = py27,pep8

[testenv]
deps =
    -r{toxinidir}/requirements.txt
    -r{toxinidir}/test-requirements.txt
commands = pytest

[testenv:pep8]
commands = flake8 {posargs}

[flake8]
show-source = true
exclude =
    .tox,
    .git,
    .venv,
    dist,
    doc
    *.egg,
    build
