[flake8]
show-source = true
exclude =
    .tox,
    .git,
    .venv,
    dist,
    doc
    *.egg,
    build
max-line-length = 88
select = C,E,F,W,B,B950
extend-ignore = E203, E501

[tool:pytest]
testpaths = tests

[coverage:run]
source = {{ package_name | underscore }}
