from flask import Blueprint
from flask_restplus import Api

from flask_api.api.resources.v1.product import api as product_ns

blueprint = Blueprint('api', __name__, url_prefix='/v1')

api = Api(
    blueprint,
    title='My Flask API',
    version='0.1',
)

api.add_namespace(product_ns)
