AllCops:
  TargetRubyVersion: {{ ruby_version }}

StringLiterals:
  EnforcedStyle: single_quotes

DotPosition:
  EnforcedStyle: leading

Metrics/LineLength:
  Max: 120

Documentation:
  Enabled: false
