# frozen_string_literal: true

require 'bundler/setup'
require 'pry'
require '{{ gem_name | underscore }}'

Dir[File.join(File.dirname(__FILE__), 'support/shared_contexts/**/*.rb')].each do |file|
  require file
end

RSpec.configure do |config|
  config.color = true
  config.order = 'random'
  config.formatter = :documentation
  config.disable_monkey_patching!
  config.filter_run_when_matching :focus
  config.example_status_persistence_file_path = '.rspec_status'
  config.shared_context_metadata_behavior = :apply_to_host_groups

  config.mock_with :rspec do |mocks|
    mocks.verify_partial_doubles = true
  end

  config.expect_with :rspec do |expectations|
    expectations.syntax = :expect
    expectations.include_chain_clauses_in_custom_matcher_descriptions = true
  end
end
