# {{ gem_name | humanize }}

{{ description }}

## Installation

Add this line to your application's Gemfile:

```
gem '{{ gem_name | underscore }}'
```

And then execute:

```bash
$ bundle
```

Or install it yourself as:

```bash
$ gem install {{ gem_name | underscore }}
```

## Usage

TODO: Write usage instructions
