[tox]
envlist = py39

[testenv]
deps =
    -r{toxinidir}/requirements.txt
    -r{toxinidir}/test-requirements.txt
changedir = {toxinidir}
commands =
    coverage erase
    coverage run -m pytest {posargs}

[testenv:test-tools]
basepython = python3
deps =
    -r{toxinidir}/test-requirements.txt
commands = {posargs}
