VARS = [
    {"name": "package_name", "required": True, "example": "fancy_package"},
    {"name": "description", "example": "Super fancy package"},
    {"name": "url", "example": "https://github.com/username/package_name"},
    {"name": "license", "default": "MIT"},
    {"name": "author", "example": "John Smith"},
]
