*.gem
*.rbc
/.config
/coverage/
/InstalledFiles
/pkg/
/spec/reports/
/spec/examples.txt
/test/tmp/
/test/version_tmp/
/tmp/

# Used by dotenv library to load environment variables.
.env

## Specific to RubyMotion:
build/

# Documentation cache and generated files:
/.yardoc/
/_yardoc/
/doc/
/rdoc/

# Environment normalization:
/.bundle/
/vendor/bundle
/lib/bundler/man/

.rspec_status
