VARS = [
    {"name": "plate_name", "required": True, "example": "fancy_plate"},
    {"name": "description", "required": True, "example": "Super fancy plate"},
    {"name": "author", "example": "John Smith"},
]
