# frozen_string_literal: true

$LOAD_PATH.push File.expand_path('lib', __dir__)
require '{{ gem_name | underscore }}/version'

Gem::Specification.new do |spec|
  spec.name = '{{ gem_name | underscore }}'
  spec.version = {{ gem_name | camelize }}::VERSION
  spec.authors = ['{{ author }}']
  {% if email %}
  spec.email = ['{{ email }}']
  {% endif %}
  {% if url %}
  spec.homepage = '{{ url }}'
  {% endif %}
  spec.summary = '{{ description }}'
  {% if license %}
  spec.license = '{{ license }}'
  {% endif %}

  spec.required_ruby_version = '~> {{ ruby_version }}'

  spec.add_development_dependency 'pry', '~> 0.10'
  spec.add_development_dependency 'rake', '~> 12.3'
  spec.add_development_dependency 'rspec', '~> 3.7'
  spec.add_development_dependency 'rubocop', '~> 0.57'

  spec.files = Dir['lib/**/*']
  spec.require_paths = ['lib']
end
