VARS = [
    {'name': '{{ plate_name | underscore }}_name',
     'required': True,
     'example': 'fancy_{{ plate_name | underscore }}'},
    {'name': 'description',
     'example': 'Super fancy {{ plate_name | humanize }}'}
]
