VARS = [
    {"name": "role_name", "required": True, "example": "redis"},
    {"name": "description", "example": "Role for setting Redis instance up"},
    {"name": "license", "default": "MIT"},
    {"name": "author", "example": "John Smith"},
]
