# {{ plate_name | humanize }}

{{ description }}

## Features

TODO: Describe features provided by the template:
    * What dependencies are installed and configured
    * What optimizations and best practices have been introduced
    * Links to helpful articles and guides

## Variables

| Name | Description | Example
| ------------- | ------------- |
| {{ plate_name | underscore }}_name  | Name of the {{ plate_name | humanize }} | fancy_{{ plate_name | underscore }} |
| description  | Description of the {{ plate_name | humanize }} | Super fancy {{ plate_name | humanize }} |

## Usage

TODO: Write usage instructions:
    * How to generate the template and what options to use depending on the use cases
    * What are the next steps to do after generating the template
