{{ package_name | humanize }}
==============================================

Installation
------------

Use pip or easy_install::

    $ pip install {{ package_name | underscore }}

Usage
-----

TODO: Write usage instructions
