VARS = [
    {"name": "gem_name", "required": True, "example": "fancy_gem"},
    {"name": "ruby_version", "required": True, "example": "2.5.1"},
    {"name": "description", "required": True, "example": "Super fancy gem"},
    {"name": "author", "required": True, "example": "John Smith"},
    {"name": "url", "example": "https://github.com/username/gem_name"},
    {"name": "license", "default": "MIT"},
    {"name": "email"},
]
