class {{ package_name | camelize }}Error(Exception):

    message = "An unknown exception occurred."

    def __init__(self, **kwargs):
        msg = self.message % kwargs
        super({{package_name | camelize}}Error, self).__init__(msg)
