from setuptools import setup, find_packages


def readme():
    with open('README.rst') as f:
        return f.read()


def get_requirements():
    with open('requirements.txt') as requirements:
        return requirements.read().splitlines()


setup(
    name='flask_api',
    version='0.1.0',
    description='flask_api',
    long_description=readme(),
    url='flask_api',
    author='flask_api',
    license='flask_api',
    install_requires=get_requirements(),
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'flask-api = flask_api.cmd.api:main'
        ]
    },
    zip_safe=False)
